@@ -1,8 +1,7 @@
 import fusion
-from fusion.entity_library import entity_type
-from fusion.entity_library.entity import Entity
-from fusion.pubsub import Channel
-from fusion.pubsub.main_loop import NoMainLoop
+from fusion.libs.entity import entity_type, Entity
+from fusion.libs.channel import Channel
+from fusion.loop import NoMainLoop
 
 
 def test_pubsub():
